@@ -9,7 +9,9 @@ from os import walk as os_walk
 from os import path as os_path
 from dataclasses import dataclass
 from shutil import copy2 as shutil_copy2
+from shutil import rmtree as shutil_rmtree
 from os import chmod as os_chmod
+from zipfile import ZipFile
 
 # Project imports
 from pydotfiles.v4.common import Configuration
@@ -32,17 +34,18 @@ class Builder:
     without requiring users to commit to a whole dynamically updated ecosystem
     """
 
-    def __init__(self, configurations: list[Configuration], base_dir: Path):
+    def __init__(self, configurations: list[Configuration], base_dir: Path, output_path: Path, is_release: bool):
         # Maps from a given profile name to the file paths that are defined there
         self.profile_map: Dict[str, list[Path]] = defaultdict(list)
         self.profile_dependencies: Dict[str, list[str]] = defaultdict(list)
         self.profile_file_types: Dict[Path, type] = {}
-        # self.manifests: Dict[Path, AlphaManifest] = {}
         self.dev_environments: Dict[Path, AlphaDeveloperEnvironments] = {}
         self.default_settings: Dict[Path, AlphaDefaultSettings] = {}
         self.core: Dict[Path, AlphaCore] = {}
         self.defined_os: set[OSName] = set()
         self.base_dir = base_dir
+        self.output_path = output_path
+        self.is_release = is_release
 
         for configuration in configurations:
             if isinstance(configuration.data, AlphaCore):
@@ -52,7 +55,6 @@ class Builder:
                 if configuration.data.os is not None:
                     self.defined_os.add(configuration.data.os.name)
             elif isinstance(configuration.data, AlphaManifest):
-                # self.manifests[configuration.file_path] = configuration.data
                 for profile in configuration.data.profiles:
                     dependencies = self.profile_dependencies[profile.name]
                     for dependency in profile.dependencies:
@@ -68,6 +70,10 @@ class Builder:
                 self.profile_file_types[configuration.file_path] = AlphaDefaultSettings
 
     def build(self, profiles: Optional[list[str]], specified_oses: Optional[list[str]]) -> Dict[str, Path]:
+        # Clears out the current build directory
+        shutil_rmtree(self.output_path)
+        self.output_path.mkdir(parents=True, exist_ok=True)
+
         active_profiles = self.__get_active_profiles(profiles)
         package_paths: Dict[str, Path] = {}
 
@@ -129,8 +135,11 @@ class Builder:
         return combined_dependencies
 
     def __build_package(self, build_data: list[Configuration], active_os: OSName, active_profile: str) -> Path:
-        dirpath = Path(mktempdir(None, f"pydotfiles-{datetime.now().isoformat()}-{active_os.value}-{active_profile}-"))
-        # build_data = self.__consolidate_requirements(build_data)
+        dirpath = self.output_path.joinpath(f"dotfiles-{active_os.value}-{active_profile}")
+        dirpath.mkdir(parents=True, exist_ok=True)
+
+        # The following line when uncommented will write to a temp directory instead
+        # dirpath = Path(mktempdir(None, f"pydotfiles-{datetime.now().isoformat()}-{active_os.value}-{active_profile}-"))
 
         is_installation_init_written = False
         for build_datum in build_data:
@@ -141,6 +150,9 @@ class Builder:
                 is_installation_init_written = True
             package_builder.build()
             package_builder.write_tail()
+
+            if self.is_release:
+                self.__zip_dir(dirpath)
         return dirpath
 
     def __consolidate_requirements(self, build_data: list[Configuration]) -> list[Configuration]:
@@ -219,6 +231,13 @@ class Builder:
             data=AlphaCore.from_dict(consolidated_data)
         )
 
+    def __zip_dir(self, directory: Path) -> Path:
+        destination = Path(f"{directory}.zip")
+        with ZipFile(destination, mode='w') as zip_fp:
+            for content in directory.iterdir():
+                zip_fp.write(content, content.name)
+        return destination
+
 ##
 # Build package methods
 ##
